@@ -4,7 +4,6 @@ package
 use strict;
 use warnings;
 
-use base 'DBIx::Class';
 
 =head1 NAME
 
@@ -12,13 +11,13 @@ DBIx::Class::CDBICompat::ColumnsAsHash - Emulates the behavior of Class::DBI whe
 
 =head1 SYNOPSIS
 
-See DBIx::Class::CDBICompat for usage directions.
+See DBIx::Class::CDBICompat for directions for use.
 
 =head1 DESCRIPTION
 
-Emulates the I<undocumented> behavior of Class::DBI where the object can be accessed as a hash of columns.  This is often used as a performance hack.
+Emulates the I<undocumnted> behavior of Class::DBI where the object can be accessed as a hash of columns.  This is often used as a performance hack.
 
-    my $column = $result->{column};
+    my $column = $row->{column};
 
 =head2 Differences from Class::DBI
 
@@ -40,16 +39,16 @@ sub inflate_result {
     my $class = shift;
 
     my $new = $class->next::method(@_);
-
+    
     $new->_make_columns_as_hash;
-
+    
     return $new;
 }
 
 
 sub _make_columns_as_hash {
     my $self = shift;
-
+    
     for my $col ($self->columns) {
         if( exists $self->{$col} ) {
             warn "Skipping mapping $col to a hash key because it exists";
@@ -103,17 +102,4 @@ sub STORE {
                 : $obj->set_column($col => shift);
 }
 
-=head1 FURTHER QUESTIONS?
-
-Check the list of L<additional DBIC resources|DBIx::Class/GETTING HELP/SUPPORT>.
-
-=head1 COPYRIGHT AND LICENSE
-
-This module is free software L<copyright|DBIx::Class/COPYRIGHT AND LICENSE>
-by the L<DBIx::Class (DBIC) authors|DBIx::Class/AUTHORS>. You can
-redistribute it and/or modify it under the same terms as the
-L<DBIx::Class library|DBIx::Class/COPYRIGHT AND LICENSE>.
-
-=cut
-
 1;
