@@ -13,7 +13,7 @@ DBIx::Class::Storage::DBI::Replicated::Balancer::Random - A 'random' Balancer
 
 This class is used internally by L<DBIx::Class::Storage::DBI::Replicated>.  You
 shouldn't need to create instances of this class.
-
+    
 =head1 DESCRIPTION
 
 Given a pool (L<DBIx::Class::Storage::DBI::Replicated::Pool>) of replicated
@@ -78,16 +78,13 @@ sub _random_number {
   rand($_[1])
 }
 
-=head1 FURTHER QUESTIONS?
+=head1 AUTHOR
 
-Check the list of L<additional DBIC resources|DBIx::Class/GETTING HELP/SUPPORT>.
+John Napiorkowski <john.napiorkowski@takkle.com>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE
 
-This module is free software L<copyright|DBIx::Class/COPYRIGHT AND LICENSE>
-by the L<DBIx::Class (DBIC) authors|DBIx::Class/AUTHORS>. You can
-redistribute it and/or modify it under the same terms as the
-L<DBIx::Class library|DBIx::Class/COPYRIGHT AND LICENSE>.
+You may distribute this code under the same terms as Perl itself.
 
 =cut
 
